@@ -1,4 +1,3 @@
-#![feature(test)]
 #![allow(deprecated)]
 
 use swc_common::chain;
@@ -1791,7 +1790,7 @@ function (A1) {
 
     _foo.set(_assertThisInitialized(_this), {
       writable: true,
-      value: _get(_getPrototypeOf(B.prototype), "foo", _assertThisInitialized(_this))()
+      value: _get(_getPrototypeOf(B.prototype), "foo", _assertThisInitialized(_this)).call(_this)
     });
 
     return _this;
@@ -3779,7 +3778,7 @@ var qux = function() {
 
 (function () {
   class Baz {
-    constructor(force1){
+    constructor(force){
       _defineProperty(this, 'fn', (function() {
         return console.log(this);
       }).bind(this));
@@ -5542,3 +5541,26 @@ test!(
     }
     "
 );
+
+test!(
+    syntax(),
+    |_| class_properties(),
+    issue_2021_1,
+    "
+    class Item extends Component {
+      constructor(props) {
+        super(props);
+      }
+    
+      input = this.props.item;
+    }
+    ",
+    "
+    class Item extends Component {
+        constructor(props){
+            super(props);
+            _defineProperty(this, 'input', this.props.item);
+        }
+    }
+    "
+);
